# fal plugin for LiveKit Agents

Support for speech-to-text with [fal.ai](https://fal.ai/).

See [https://docs.livekit.io/agents/integrations/stt/fal/](https://docs.livekit.io/agents/integrations/stt/fal/) for more information.

## Installation

```bash
pip install livekit-plugins-fal
```

## Pre-requisites

You'll need an API key from fal. It can be set as an environment variable: `FAL_KEY`
